Prints a timestamped stage message when verbose is TRUE. If
interactive_only is TRUE the message is printed only during interactive
sessions. When the TESTTHAT environment variable is "true",
messages are suppressed even in interactive mode.
Prints a timestamped stage message when verbose is TRUE. If
interactive_only is TRUE the message is printed only during interactive
sessions. When the TESTTHAT environment variable is "true",
messages are suppressed even in interactive mode.